summaryrefslogtreecommitdiff
path: root/xmloff/source/style
diff options
context:
space:
mode:
Diffstat (limited to 'xmloff/source/style')
-rw-r--r--xmloff/source/style/EnumPropertyHdl.cxx2
-rw-r--r--xmloff/source/style/FillStyleContext.cxx12
-rw-r--r--xmloff/source/style/FillStyleContext.hxx12
-rw-r--r--xmloff/source/style/MarkerStyle.cxx6
-rw-r--r--xmloff/source/style/PageHeaderFooterContext.cxx4
-rw-r--r--xmloff/source/style/PageHeaderFooterContext.hxx4
-rw-r--r--xmloff/source/style/PagePropertySetContext.hxx2
-rw-r--r--xmloff/source/style/TransGradientStyle.cxx4
-rw-r--r--xmloff/source/style/VisAreaContext.cxx8
-rw-r--r--xmloff/source/style/XMLFontAutoStylePool.cxx4
-rw-r--r--xmloff/source/style/chrhghdl.cxx2
-rw-r--r--xmloff/source/style/fonthdl.cxx8
-rw-r--r--xmloff/source/style/impastp4.cxx18
-rw-r--r--xmloff/source/style/makefile.mk2
-rw-r--r--xmloff/source/style/styleexp.cxx2
-rw-r--r--xmloff/source/style/weighhdl.cxx2
-rw-r--r--xmloff/source/style/xmlimppr.cxx10
-rw-r--r--xmloff/source/style/xmlnume.cxx4
-rw-r--r--xmloff/source/style/xmlnumfe.cxx20
-rw-r--r--xmloff/source/style/xmlnumfi.cxx122
-rw-r--r--xmloff/source/style/xmlnumi.cxx10
-rw-r--r--xmloff/source/style/xmlprcon.cxx6
-rw-r--r--xmloff/source/style/xmlstyle.cxx6
23 files changed, 135 insertions, 135 deletions
diff --git a/xmloff/source/style/EnumPropertyHdl.cxx b/xmloff/source/style/EnumPropertyHdl.cxx
index 72b399be47a8..0c01ba9e6db9 100644
--- a/xmloff/source/style/EnumPropertyHdl.cxx
+++ b/xmloff/source/style/EnumPropertyHdl.cxx
@@ -52,7 +52,7 @@ XMLEnumPropertyHdl::~XMLEnumPropertyHdl()
sal_Bool XMLEnumPropertyHdl::importXML( const OUString& rStrImpValue, Any& rValue, const SvXMLUnitConverter& ) const
{
- USHORT nValue = 0;
+ sal_uInt16 nValue = 0;
if( SvXMLUnitConverter::convertEnum( nValue, rStrImpValue, mpEnumMap ) )
{
diff --git a/xmloff/source/style/FillStyleContext.cxx b/xmloff/source/style/FillStyleContext.cxx
index 311448fe96bb..416042cfb9bc 100644
--- a/xmloff/source/style/FillStyleContext.cxx
+++ b/xmloff/source/style/FillStyleContext.cxx
@@ -90,7 +90,7 @@ void XMLGradientStyleContext::EndElement()
{}
}
-BOOL XMLGradientStyleContext::IsTransient() const
+sal_Bool XMLGradientStyleContext::IsTransient() const
{
return sal_True;
}
@@ -136,7 +136,7 @@ void XMLHatchStyleContext::EndElement()
{}
}
-BOOL XMLHatchStyleContext::IsTransient() const
+sal_Bool XMLHatchStyleContext::IsTransient() const
{
return sal_True;
}
@@ -216,7 +216,7 @@ void XMLBitmapStyleContext::EndElement()
{}
}
-BOOL XMLBitmapStyleContext::IsTransient() const
+sal_Bool XMLBitmapStyleContext::IsTransient() const
{
return sal_True;
}
@@ -263,7 +263,7 @@ void XMLTransGradientStyleContext::EndElement()
{}
}
-BOOL XMLTransGradientStyleContext::IsTransient() const
+sal_Bool XMLTransGradientStyleContext::IsTransient() const
{
return sal_True;
}
@@ -309,7 +309,7 @@ void XMLMarkerStyleContext::EndElement()
{}
}
-BOOL XMLMarkerStyleContext::IsTransient() const
+sal_Bool XMLMarkerStyleContext::IsTransient() const
{
return sal_True;
}
@@ -355,7 +355,7 @@ void XMLDashStyleContext::EndElement()
{}
}
-BOOL XMLDashStyleContext::IsTransient() const
+sal_Bool XMLDashStyleContext::IsTransient() const
{
return sal_True;
}
diff --git a/xmloff/source/style/FillStyleContext.hxx b/xmloff/source/style/FillStyleContext.hxx
index 52346781d0a6..32d448cbb0b1 100644
--- a/xmloff/source/style/FillStyleContext.hxx
+++ b/xmloff/source/style/FillStyleContext.hxx
@@ -50,7 +50,7 @@ public:
virtual void EndElement();
- virtual BOOL IsTransient() const;
+ virtual sal_Bool IsTransient() const;
};
//////////////////////////////////////////////////////////////////////////////
@@ -71,7 +71,7 @@ public:
virtual void EndElement();
- virtual BOOL IsTransient() const;
+ virtual sal_Bool IsTransient() const;
};
//////////////////////////////////////////////////////////////////////////////
@@ -98,7 +98,7 @@ public:
virtual void EndElement();
- virtual BOOL IsTransient() const;
+ virtual sal_Bool IsTransient() const;
};
//////////////////////////////////////////////////////////////////////////////
@@ -119,7 +119,7 @@ public:
virtual void EndElement();
- virtual BOOL IsTransient() const;
+ virtual sal_Bool IsTransient() const;
};
//////////////////////////////////////////////////////////////////////////////
@@ -140,7 +140,7 @@ public:
virtual void EndElement();
- virtual BOOL IsTransient() const;
+ virtual sal_Bool IsTransient() const;
};
//////////////////////////////////////////////////////////////////////////////
@@ -161,7 +161,7 @@ public:
virtual void EndElement();
- virtual BOOL IsTransient() const;
+ virtual sal_Bool IsTransient() const;
};
#endif // _XMLOFF_FILLSTYLECONTEXTS_HXX_
diff --git a/xmloff/source/style/MarkerStyle.cxx b/xmloff/source/style/MarkerStyle.cxx
index 4835691b5909..7f134bd65176 100644
--- a/xmloff/source/style/MarkerStyle.cxx
+++ b/xmloff/source/style/MarkerStyle.cxx
@@ -212,7 +212,7 @@ sal_Bool XMLMarkerStyleExport::exportXML(
sal_Int32 a, b;
sal_Bool bClosed(sal_False);
- for(a = 0L; a < nOuterCnt; a++)
+ for (a = 0; a < nOuterCnt; a++)
{
drawing::PointSequence* pSequence = pOuterSequence++;
const awt::Point *pPoints = pSequence->getConstArray();
@@ -229,7 +229,7 @@ sal_Bool XMLMarkerStyleExport::exportXML(
}
}
- for(b = 0L; b < nPointCount; b++)
+ for (b = 0; b < nPointCount; b++)
{
const awt::Point aPoint = pPoints[b];
@@ -259,7 +259,7 @@ sal_Bool XMLMarkerStyleExport::exportXML(
drawing::FlagSequence* pOuterFlags = aBezier.Flags.getArray();
SdXMLImExSvgDElement aSvgDElement(aViewBox);
- for(a = 0L; a < nOuterCnt; a++)
+ for (a = 0; a < nOuterCnt; a++)
{
drawing::PointSequence* pSequence = pOuterSequence++;
drawing::FlagSequence* pFlags = pOuterFlags++;
diff --git a/xmloff/source/style/PageHeaderFooterContext.cxx b/xmloff/source/style/PageHeaderFooterContext.cxx
index 571c001d00de..c5f556df501d 100644
--- a/xmloff/source/style/PageHeaderFooterContext.cxx
+++ b/xmloff/source/style/PageHeaderFooterContext.cxx
@@ -47,7 +47,7 @@ using ::xmloff::token::XML_HEADER_FOOTER_PROPERTIES;
//------------------------------------------------------------------
PageHeaderFooterContext::PageHeaderFooterContext( SvXMLImport& rImport,
- USHORT nPrfx,
+ sal_uInt16 nPrfx,
const rtl::OUString& rLName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>&,
@@ -68,7 +68,7 @@ PageHeaderFooterContext::~PageHeaderFooterContext()
{
}
-SvXMLImportContext *PageHeaderFooterContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *PageHeaderFooterContext::CreateChildContext( sal_uInt16 nPrefix,
const rtl::OUString& rLName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList )
diff --git a/xmloff/source/style/PageHeaderFooterContext.hxx b/xmloff/source/style/PageHeaderFooterContext.hxx
index 50dcebd1ccd8..e5b437f2ce21 100644
--- a/xmloff/source/style/PageHeaderFooterContext.hxx
+++ b/xmloff/source/style/PageHeaderFooterContext.hxx
@@ -39,7 +39,7 @@ class PageHeaderFooterContext : public SvXMLImportContext
public:
- PageHeaderFooterContext( SvXMLImport& rImport, USHORT nPrfx,
+ PageHeaderFooterContext( SvXMLImport& rImport, sal_uInt16 nPrfx,
const rtl::OUString& rLName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList,
@@ -50,7 +50,7 @@ public:
virtual ~PageHeaderFooterContext();
- virtual SvXMLImportContext *CreateChildContext( USHORT nPrefix,
+ virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
const rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
diff --git a/xmloff/source/style/PagePropertySetContext.hxx b/xmloff/source/style/PagePropertySetContext.hxx
index eda42b5dcff8..3bb0f2e84d04 100644
--- a/xmloff/source/style/PagePropertySetContext.hxx
+++ b/xmloff/source/style/PagePropertySetContext.hxx
@@ -55,7 +55,7 @@ public:
virtual ~PagePropertySetContext();
using SvXMLPropertySetContext::CreateChildContext;
- virtual SvXMLImportContext *CreateChildContext( USHORT nPrefix,
+ virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
const ::rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList,
::std::vector< XMLPropertyState > &rProperties,
diff --git a/xmloff/source/style/TransGradientStyle.cxx b/xmloff/source/style/TransGradientStyle.cxx
index 7e0456e5db25..1357fee3e7f7 100644
--- a/xmloff/source/style/TransGradientStyle.cxx
+++ b/xmloff/source/style/TransGradientStyle.cxx
@@ -169,7 +169,7 @@ sal_Bool XMLTransGradientStyleImport::importXML(
sal_Int32 aStartTransparency;
SvXMLUnitConverter::convertPercent( aStartTransparency, rStrValue );
- UINT8 n = sal::static_int_cast< UINT8 >(
+ sal_uInt8 n = sal::static_int_cast< sal_uInt8 >(
( (100 - aStartTransparency) * 255 ) / 100 );
Color aColor( n, n, n );
@@ -181,7 +181,7 @@ sal_Bool XMLTransGradientStyleImport::importXML(
sal_Int32 aEndTransparency;
SvXMLUnitConverter::convertPercent( aEndTransparency, rStrValue );
- UINT8 n = sal::static_int_cast< UINT8 >(
+ sal_uInt8 n = sal::static_int_cast< sal_uInt8 >(
( (100 - aEndTransparency) * 255 ) / 100 );
Color aColor( n, n, n );
diff --git a/xmloff/source/style/VisAreaContext.cxx b/xmloff/source/style/VisAreaContext.cxx
index 9d9b34c2159c..8688d2fc95ea 100644
--- a/xmloff/source/style/VisAreaContext.cxx
+++ b/xmloff/source/style/VisAreaContext.cxx
@@ -46,7 +46,7 @@ using namespace ::xmloff::token;
//------------------------------------------------------------------
XMLVisAreaContext::XMLVisAreaContext( SvXMLImport& rImport,
- USHORT nPrfx,
+ sal_uInt16 nPrfx,
const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& xAttrList,
Rectangle& rRect, const MapUnit aMapUnit ) :
@@ -62,7 +62,7 @@ XMLVisAreaContext::XMLVisAreaContext( SvXMLImport& rImport,
}
XMLVisAreaContext::XMLVisAreaContext( SvXMLImport& rImport,
- USHORT nPrfx,
+ sal_uInt16 nPrfx,
const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& xAttrList,
::com::sun::star::awt::Rectangle& rRect, const sal_Int16 nMeasureUnit ) :
@@ -88,7 +88,7 @@ void XMLVisAreaContext::process( const uno::Reference< xml::sax::XAttributeList>
{
rtl::OUString sAttrName = xAttrList->getNameByIndex( i );
rtl::OUString aLocalName;
- USHORT nPrefix = GetImport().GetNamespaceMap().GetKeyByAttrName(
+ sal_uInt16 nPrefix = GetImport().GetNamespaceMap().GetKeyByAttrName(
sAttrName, &aLocalName );
rtl::OUString sValue = xAttrList->getValueByIndex( i );
@@ -118,7 +118,7 @@ void XMLVisAreaContext::process( const uno::Reference< xml::sax::XAttributeList>
}
}
-SvXMLImportContext *XMLVisAreaContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *XMLVisAreaContext::CreateChildContext( sal_uInt16 nPrefix,
const rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& )
diff --git a/xmloff/source/style/XMLFontAutoStylePool.cxx b/xmloff/source/style/XMLFontAutoStylePool.cxx
index dcc81ccf9f89..3c8a55effd47 100644
--- a/xmloff/source/style/XMLFontAutoStylePool.cxx
+++ b/xmloff/source/style/XMLFontAutoStylePool.cxx
@@ -174,7 +174,7 @@ OUString XMLFontAutoStylePool::Add(
OUString sPoolName;
XMLFontAutoStylePoolEntry_Impl aTmp( rFamilyName, rStyleName, nFamily,
nPitch, eEnc );
- ULONG nPos;
+ sal_uIntPtr nPos;
if( pPool->Seek_Entry( &aTmp, &nPos ) )
{
sPoolName = pPool->GetObject( nPos )->GetName();
@@ -228,7 +228,7 @@ OUString XMLFontAutoStylePool::Add(
OUString sName;
XMLFontAutoStylePoolEntry_Impl aTmp( rFamilyName, rStyleName, nFamily,
nPitch, eEnc );
- ULONG nPos;
+ sal_uIntPtr nPos;
if( pPool->Seek_Entry( &aTmp, &nPos ) )
{
sName = pPool->GetObject( nPos )->GetName();
diff --git a/xmloff/source/style/chrhghdl.cxx b/xmloff/source/style/chrhghdl.cxx
index 1a70696583d2..bb27a1378eab 100644
--- a/xmloff/source/style/chrhghdl.cxx
+++ b/xmloff/source/style/chrhghdl.cxx
@@ -79,7 +79,7 @@ sal_Bool XMLCharHeightHdl::exportXML( OUString& rStrExpValue, const uno::Any& rV
float fSize = 0;
if( rValue >>= fSize )
{
- SvXMLUnitConverter::convertDouble( aOut, (double)fSize, TRUE, MAP_POINT, MAP_POINT );
+ SvXMLUnitConverter::convertDouble( aOut, (double)fSize, sal_True, MAP_POINT, MAP_POINT );
aOut.append( sal_Unicode('p'));
aOut.append( sal_Unicode('t'));
}
diff --git a/xmloff/source/style/fonthdl.cxx b/xmloff/source/style/fonthdl.cxx
index 89ad6e9db8b8..d7e6bd7d1725 100644
--- a/xmloff/source/style/fonthdl.cxx
+++ b/xmloff/source/style/fonthdl.cxx
@@ -136,12 +136,12 @@ sal_Bool XMLFontFamilyNamePropHdl::exportXML( OUString& rStrExpValue, const uno:
if( rValue >>= aStrFamilyName )
{
OUStringBuffer sValue( aStrFamilyName.getLength() + 2L );
- sal_Int32 nPos = 0L;
+ sal_Int32 nPos = 0;
do
{
sal_Int32 nFirst = nPos;
nPos = aStrFamilyName.indexOf( sal_Unicode(';'), nPos );
- sal_Int32 nLast = (-1L == nPos ? aStrFamilyName.getLength() : nPos);
+ sal_Int32 nLast = (-1 == nPos ? aStrFamilyName.getLength() : nPos);
// Set position to the character behind the ';', so we won't
// forget this.
@@ -173,7 +173,7 @@ sal_Bool XMLFontFamilyNamePropHdl::exportXML( OUString& rStrExpValue, const uno:
sValue.append( sal_Unicode( ',' ) );
sValue.append( sal_Unicode( ' ' ));
}
- sal_Int32 nLen = nLast-nFirst+1L;
+ sal_Int32 nLen = nLast-nFirst+1;
OUString sFamily( aStrFamilyName.copy( nFirst, nLen ) );
sal_Bool bQuote = sal_False;
for( sal_Int32 i=0; i < nLen; i++ )
@@ -291,7 +291,7 @@ XMLFontPitchPropHdl::~XMLFontPitchPropHdl()
sal_Bool XMLFontPitchPropHdl::importXML( const OUString& rStrImpValue, uno::Any& rValue, const SvXMLUnitConverter& ) const
{
- USHORT eNewPitch;
+ sal_uInt16 eNewPitch;
sal_Bool bRet = SvXMLUnitConverter::convertEnum( eNewPitch, rStrImpValue, aFontPitchMapping );
if( bRet )
rValue <<= (sal_Int16)eNewPitch;
diff --git a/xmloff/source/style/impastp4.cxx b/xmloff/source/style/impastp4.cxx
index af3f36d8b4d1..0eb615ea2834 100644
--- a/xmloff/source/style/impastp4.cxx
+++ b/xmloff/source/style/impastp4.cxx
@@ -67,7 +67,7 @@ SvXMLAutoStylePoolP_Impl::SvXMLAutoStylePoolP_Impl( SvXMLExport& rExp)
SvXMLAutoStylePoolP_Impl::~SvXMLAutoStylePoolP_Impl()
{
for (;;) {
- XMLFamilyData_Impl* pData = maFamilyList.Remove( ULONG(0) );
+ XMLFamilyData_Impl* pData = maFamilyList.Remove( sal_uIntPtr(0) );
if (pData == NULL) {
break;
}
@@ -88,7 +88,7 @@ void SvXMLAutoStylePoolP_Impl::AddFamily(
sal_Bool bAsFamily )
{
// store family in a list if not already stored
- ULONG nPos;
+ sal_uIntPtr nPos;
sal_uInt16 nExportFlags = GetExport().getExportFlags();
sal_Bool bStylesOnly = (nExportFlags & EXPORT_STYLES) != 0 && (nExportFlags & EXPORT_CONTENT) == 0;
@@ -116,7 +116,7 @@ void SvXMLAutoStylePoolP_Impl::RegisterName( sal_Int32 nFamily, const OUString&
{
SvXMLAutoStylePoolNamesP_Impl *pNames = 0;
- ULONG nPos;
+ sal_uIntPtr nPos;
XMLFamilyData_Impl aTmp( nFamily );
if( maFamilyList.Seek_Entry( &aTmp, &nPos ) )
pNames = maFamilyList.GetObject( nPos )->mpNameList;
@@ -187,7 +187,7 @@ sal_Bool SvXMLAutoStylePoolP_Impl::Add(OUString& rName, sal_Int32 nFamily,
bool bDontSeek )
{
sal_Bool bRet(sal_False);
- ULONG nPos;
+ sal_uIntPtr nPos;
XMLFamilyData_Impl *pFamily = 0;
XMLFamilyData_Impl aTemporary( nFamily );
@@ -237,7 +237,7 @@ sal_Bool SvXMLAutoStylePoolP_Impl::AddNamed(const OUString& rName, sal_Int32 nFa
{
// get family and parent the same way as in Add()
sal_Bool bRet(sal_False);
- ULONG nPos;
+ sal_uIntPtr nPos;
XMLFamilyData_Impl *pFamily = 0;
XMLFamilyData_Impl aTemporary( nFamily );
@@ -276,7 +276,7 @@ sal_Bool SvXMLAutoStylePoolP_Impl::AddNamed(const OUString& rName, sal_Int32 nFa
OUString SvXMLAutoStylePoolP_Impl::AddToCache( sal_Int32 nFamily,
const OUString& rParent )
{
- ULONG nPos;
+ sal_uIntPtr nPos;
XMLFamilyData_Impl *pFamily = 0;
XMLFamilyData_Impl aTmp( nFamily );
@@ -308,7 +308,7 @@ OUString SvXMLAutoStylePoolP_Impl::Find( sal_Int32 nFamily,
{
OUString sName;
- ULONG nPos;
+ sal_uIntPtr nPos;
XMLFamilyData_Impl aTemporary( nFamily );
XMLFamilyData_Impl *pFamily = 0;
if( maFamilyList.Seek_Entry( &aTemporary, &nPos ) )
@@ -335,7 +335,7 @@ OUString SvXMLAutoStylePoolP_Impl::FindAndRemoveCached( sal_Int32 nFamily ) cons
{
OUString sName;
- ULONG nPos;
+ sal_uIntPtr nPos;
XMLFamilyData_Impl aTmp( nFamily );
XMLFamilyData_Impl *pFamily = 0;
if( maFamilyList.Seek_Entry( &aTmp, &nPos ) )
@@ -377,7 +377,7 @@ void SvXMLAutoStylePoolP_Impl::exportXML(
sal_uInt32 nCount = 0;
// Get list of parents for current family (nFamily)
- ULONG nPos;
+ sal_uIntPtr nPos;
XMLFamilyData_Impl aTmp( nFamily );
XMLFamilyData_Impl *pFamily = 0;
if( maFamilyList.Seek_Entry( &aTmp, &nPos ) )
diff --git a/xmloff/source/style/makefile.mk b/xmloff/source/style/makefile.mk
index 3436b33b654b..75a1c35aeefc 100644
--- a/xmloff/source/style/makefile.mk
+++ b/xmloff/source/style/makefile.mk
@@ -30,7 +30,7 @@ PRJ=..$/..
PRJNAME=xmloff
TARGET=style
-ENABLE_EXCEPTIONS=TRUE
+ENABLE_EXCEPTIONS=sal_True
# --- Settings -----------------------------------------------------
diff --git a/xmloff/source/style/styleexp.cxx b/xmloff/source/style/styleexp.cxx
index cb666d899fb7..6cbf34301d5e 100644
--- a/xmloff/source/style/styleexp.cxx
+++ b/xmloff/source/style/styleexp.cxx
@@ -477,7 +477,7 @@ void XMLStyleExport::exportStyleFamily(
{
if( !bUsed || xStyle->isInUse() )
{
- BOOL bExported = exportStyle( xStyle, rXMLFamily, rPropMapper,
+ sal_Bool bExported = exportStyle( xStyle, rXMLFamily, rPropMapper,
xStyles,pPrefix );
if( bUsed && bFirstStyle && bExported )
{
diff --git a/xmloff/source/style/weighhdl.cxx b/xmloff/source/style/weighhdl.cxx
index 1765f3885cb1..e9eda292723b 100644
--- a/xmloff/source/style/weighhdl.cxx
+++ b/xmloff/source/style/weighhdl.cxx
@@ -51,7 +51,7 @@ using namespace ::xmloff::token;
struct FontWeightMapper
{
float fWeight;
- USHORT nValue;
+ sal_uInt16 nValue;
};
FontWeightMapper const aFontWeightMap[] =
diff --git a/xmloff/source/style/xmlimppr.cxx b/xmloff/source/style/xmlimppr.cxx
index 812071ff1b03..4675f9bf3c80 100644
--- a/xmloff/source/style/xmlimppr.cxx
+++ b/xmloff/source/style/xmlimppr.cxx
@@ -134,7 +134,7 @@ void SvXMLImportPropertyMapper::importXML(
sal_Int32 nStartIdx,
sal_Int32 nEndIdx ) const
{
- INT16 nAttr = xAttrList->getLength();
+ sal_Int16 nAttr = xAttrList->getLength();
Reference< XNameContainer > xAttrContainer;
@@ -142,11 +142,11 @@ void SvXMLImportPropertyMapper::importXML(
nStartIdx = 0;
if( -1 == nEndIdx )
nEndIdx = maPropMapper->GetEntryCount();
- for( INT16 i=0; i < nAttr; i++ )
+ for( sal_Int16 i=0; i < nAttr; i++ )
{
const OUString& rAttrName = xAttrList->getNameByIndex( i );
OUString aLocalName, aPrefix, aNamespace;
- USHORT nPrefix = rNamespaceMap.GetKeyByAttrName( rAttrName, &aPrefix,
+ sal_uInt16 nPrefix = rNamespaceMap.GetKeyByAttrName( rAttrName, &aPrefix,
&aLocalName, &aNamespace );
if( XML_NAMESPACE_XMLNS == nPrefix )
@@ -354,7 +354,7 @@ void SvXMLImportPropertyMapper::importXML(
}
/** this method is called for every item that has the MID_FLAG_SPECIAL_ITEM_IMPORT flag set */
-BOOL SvXMLImportPropertyMapper::handleSpecialItem(
+sal_Bool SvXMLImportPropertyMapper::handleSpecialItem(
XMLPropertyState& rProperty,
vector< XMLPropertyState >& rProperties,
const OUString& rValue,
@@ -366,7 +366,7 @@ BOOL SvXMLImportPropertyMapper::handleSpecialItem(
return mxNextMapper->handleSpecialItem( rProperty, rProperties, rValue,
rUnitConverter, rNamespaceMap );
else
- return FALSE;
+ return sal_False;
}
void SvXMLImportPropertyMapper::FillPropertySequence(
diff --git a/xmloff/source/style/xmlnume.cxx b/xmloff/source/style/xmlnume.cxx
index 5bc581c7af0b..02d9bebdbd0a 100644
--- a/xmloff/source/style/xmlnume.cxx
+++ b/xmloff/source/style/xmlnume.cxx
@@ -113,9 +113,9 @@ void SvxXMLNumRuleExport::exportLevelStyles( const uno::Reference< ::com::sun::s
}
}
-void SvxXMLNumRuleExport::exportLevelStyle( INT32 nLevel,
+void SvxXMLNumRuleExport::exportLevelStyle( sal_Int32 nLevel,
const uno::Sequence<beans::PropertyValue>& rProps,
- BOOL bOutline )
+ sal_Bool bOutline )
{
sal_Int16 eType = NumberingType::CHAR_SPECIAL;
diff --git a/xmloff/source/style/xmlnumfi.cxx b/xmloff/source/style/xmlnumfi.cxx
index a192baa2216b..8ad404d2591b 100644
--- a/xmloff/source/style/xmlnumfi.cxx
+++ b/xmloff/source/style/xmlnumfi.cxx
@@ -83,8 +83,8 @@ struct SvXMLEmbeddedElement
nFormatPos(nFP), aText(rT) {}
// comparison operators for PTRARR sorting - sorted by position
- BOOL operator ==( const SvXMLEmbeddedElement& r ) const { return nFormatPos == r.nFormatPos; }
- BOOL operator < ( const SvXMLEmbeddedElement& r ) const { return nFormatPos < r.nFormatPos; }
+ sal_Bool operator ==( const SvXMLEmbeddedElement& r ) const { return nFormatPos == r.nFormatPos; }
+ sal_Bool operator < ( const SvXMLEmbeddedElement& r ) const { return nFormatPos < r.nFormatPos; }
};
typedef SvXMLEmbeddedElement* SvXMLEmbeddedElementPtr;
@@ -159,14 +159,14 @@ class SvXMLNumFmtElementContext : public SvXMLImportContext
rtl::OUString sCalendar;
public:
- SvXMLNumFmtElementContext( SvXMLImport& rImport, USHORT nPrfx,
+ SvXMLNumFmtElementContext( SvXMLImport& rImport, sal_uInt16 nPrfx,
const rtl::OUString& rLName,
SvXMLNumFormatContext& rParentContext, sal_uInt16 nNewType,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
virtual ~SvXMLNumFmtElementContext();
- virtual SvXMLImportContext *CreateChildContext( USHORT nPrefix,
+ virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
const rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
@@ -184,14 +184,14 @@ class SvXMLNumFmtEmbeddedTextContext : public SvXMLImportContext
sal_Int32 nTextPosition;
public:
- SvXMLNumFmtEmbeddedTextContext( SvXMLImport& rImport, USHORT nPrfx,
+ SvXMLNumFmtEmbeddedTextContext( SvXMLImport& rImport, sal_uInt16 nPrfx,
const rtl::OUString& rLName,
SvXMLNumFmtElementContext& rParentContext,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
virtual ~SvXMLNumFmtEmbeddedTextContext();
- virtual SvXMLImportContext *CreateChildContext( USHORT nPrefix,
+ virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
const rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
@@ -207,14 +207,14 @@ class SvXMLNumFmtMapContext : public SvXMLImportContext
rtl::OUString sName;
public:
- SvXMLNumFmtMapContext( SvXMLImport& rImport, USHORT nPrfx,
+ SvXMLNumFmtMapContext( SvXMLImport& rImport, sal_uInt16 nPrfx,
const rtl::OUString& rLName,
SvXMLNumFormatContext& rParentContext,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
virtual ~SvXMLNumFmtMapContext();
- virtual SvXMLImportContext *CreateChildContext( USHORT nPrefix,
+ virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
const rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
@@ -230,14 +230,14 @@ class SvXMLNumFmtPropContext : public SvXMLImportContext
sal_Bool bColSet;
public:
- SvXMLNumFmtPropContext( SvXMLImport& rImport, USHORT nPrfx,
+ SvXMLNumFmtPropContext( SvXMLImport& rImport, sal_uInt16 nPrfx,
const rtl::OUString& rLName,
SvXMLNumFormatContext& rParentContext,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
virtual ~SvXMLNumFmtPropContext();
- virtual SvXMLImportContext *CreateChildContext( USHORT nPrefix,
+ virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
const rtl::OUString& rLocalName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList );
@@ -422,8 +422,8 @@ SvXMLNumImpData::~SvXMLNumImpData()
sal_uInt32 SvXMLNumImpData::GetKeyForName( const rtl::OUString& rName )
{
- USHORT nCount = aNameEntries.Count();
- for (USHORT i=0; i<nCount; i++)
+ sal_uInt16 nCount = aNameEntries.Count();
+ for (sal_uInt16 i=0; i<nCount; i++)
{
const SvXMLNumFmtEntry* pObj = aNameEntries[i];
if ( pObj->aName == rName )
@@ -439,8 +439,8 @@ void SvXMLNumImpData::AddKey( sal_uInt32 nKey, const rtl::OUString& rName, sal_B
// if there is already an entry for this key without the bRemoveAfterUse flag,
// clear the flag for this entry, too
- USHORT nCount = aNameEntries.Count();
- for (USHORT i=0; i<nCount; i++)
+ sal_uInt16 nCount = aNameEntries.Count();
+ for (sal_uInt16 i=0; i<nCount; i++)
{
SvXMLNumFmtEntry* pObj = aNameEntries[i];
if ( pObj->nKey == nKey && !pObj->bRemoveAfterUse )
@@ -462,8 +462,8 @@ void SvXMLNumImpData::AddKey( sal_uInt32 nKey, const rtl::OUString& rName, sal_B
void SvXMLNumImpData::SetUsed( sal_uInt32 nKey )
{
- USHORT nCount = aNameEntries.Count();
- for (USHORT i=0; i<nCount; i++)
+ sal_uInt16 nCount = aNameEntries.Count();
+ for (sal_uInt16 i=0; i<nCount; i++)
{
SvXMLNumFmtEntry* pObj = aNameEntries[i];
if ( pObj->nKey == nKey )
@@ -486,8 +486,8 @@ void SvXMLNumImpData::RemoveVolatileFormats()
if ( !pFormatter )
return;
- USHORT nCount = aNameEntries.Count();
- for (USHORT i=0; i<nCount; i++)
+ sal_uInt16 nCount = aNameEntries.Count();
+ for (sal_uInt16 i=0; i<nCount; i++)
{
const SvXMLNumFmtEntry* pObj = aNameEntries[i];
if ( pObj->bRemoveAfterUse )
@@ -635,7 +635,7 @@ const LocaleDataWrapper& SvXMLNumImpData::GetLocaleData( LanguageType nLang )
//
SvXMLNumFmtMapContext::SvXMLNumFmtMapContext( SvXMLImport& rImport,
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
SvXMLNumFormatContext& rParentContext,
const uno::Reference<xml::sax::XAttributeList>& xAttrList ) :
SvXMLImportContext( rImport, nPrfx, rLName ),
@@ -663,7 +663,7 @@ SvXMLNumFmtMapContext::~SvXMLNumFmtMapContext()
}
SvXMLImportContext* SvXMLNumFmtMapContext::CreateChildContext(
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& )
{
// no elements supported - use default context
@@ -686,7 +686,7 @@ void SvXMLNumFmtMapContext::EndElement()
//
SvXMLNumFmtPropContext::SvXMLNumFmtPropContext( SvXMLImport& rImport,
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
SvXMLNumFormatContext& rParentContext,
const uno::Reference<xml::sax::XAttributeList>& xAttrList ) :
SvXMLImportContext( rImport, nPrfx, rLName ),
@@ -710,7 +710,7 @@ SvXMLNumFmtPropContext::~SvXMLNumFmtPropContext()
}
SvXMLImportContext* SvXMLNumFmtPropContext::CreateChildContext(
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& )
{
// no elements supported - use default context
@@ -734,7 +734,7 @@ void SvXMLNumFmtPropContext::EndElement()
//
SvXMLNumFmtEmbeddedTextContext::SvXMLNumFmtEmbeddedTextContext( SvXMLImport& rImport,
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
SvXMLNumFmtElementContext& rParentContext,
const uno::Reference<xml::sax::XAttributeList>& xAttrList ) :
SvXMLImportContext( rImport, nPrfx, rLName ),
@@ -763,7 +763,7 @@ SvXMLNumFmtEmbeddedTextContext::~SvXMLNumFmtEmbeddedTextContext()
}
SvXMLImportContext* SvXMLNumFmtEmbeddedTextContext::CreateChildContext(
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& )
{
// no elements supported - use default context
@@ -938,15 +938,15 @@ void lcl_EnquoteIfNecessary( rtl::OUStringBuffer& rContent, const SvXMLNumFormat
//
SvXMLNumFmtElementContext::SvXMLNumFmtElementContext( SvXMLImport& rImport,
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
SvXMLNumFormatContext& rParentContext, sal_uInt16 nNewType,
const uno::Reference<xml::sax::XAttributeList>& xAttrList ) :
SvXMLImportContext( rImport, nPrfx, rLName ),
rParent( rParentContext ),
nType( nNewType ),
nElementLang( LANGUAGE_SYSTEM ),
- bLong( FALSE ),
- bTextual( FALSE )
+ bLong( sal_False ),
+ bTextual( sal_False )
{
OUString sLanguage, sCountry;
sal_Int32 nAttrVal;
@@ -1034,7 +1034,7 @@ SvXMLNumFmtElementContext::~SvXMLNumFmtElementContext()
}
SvXMLImportContext* SvXMLNumFmtElementContext::CreateChildContext(
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& xAttrList )
{
// only number:number supports number:embedded-text child element
@@ -1063,8 +1063,8 @@ void SvXMLNumFmtElementContext::AddEmbeddedElement( sal_Int32 nFormatPos, const
// there's already an element at this position - append text to existing element
delete pObj;
- USHORT nElementCount = aNumInfo.aEmbeddedElements.Count();
- for (USHORT i=0; i<nElementCount; i++)
+ sal_uInt16 nElementCount = aNumInfo.aEmbeddedElements.Count();
+ for (sal_uInt16 i=0; i<nElementCount; i++)
{
pObj = aNumInfo.aEmbeddedElements[i];
if ( pObj->nFormatPos == nFormatPos )
@@ -1266,7 +1266,7 @@ void SvXMLNumFmtElementContext::EndElement()
//-------------------------------------------------------------------------
-sal_Bool SvXMLNumFmtDefaults::IsSystemLongDay( const SvtSysLocale&, BOOL bLong )
+sal_Bool SvXMLNumFmtDefaults::IsSystemLongDay( const SvtSysLocale&, sal_Bool bLong )
{
// TODO: merge system information and defaults into i18n locale data
#if 0
@@ -1276,7 +1276,7 @@ sal_Bool SvXMLNumFmtDefaults::IsSystemLongDay( const SvtSysLocale&, BOOL bLong )
#endif
}
-sal_Bool SvXMLNumFmtDefaults::IsSystemLongMonth( const SvtSysLocale&, BOOL bLong )
+sal_Bool SvXMLNumFmtDefaults::IsSystemLongMonth( const SvtSysLocale&, sal_Bool bLong )
{
// TODO: merge system information and defaults into i18n locale data
#if 0
@@ -1292,7 +1292,7 @@ sal_Bool SvXMLNumFmtDefaults::IsSystemLongMonth( const SvtSysLocale&, BOOL bLong
#endif
}
-sal_Bool SvXMLNumFmtDefaults::IsSystemTextualMonth( const SvtSysLocale&, BOOL bLong )
+sal_Bool SvXMLNumFmtDefaults::IsSystemTextualMonth( const SvtSysLocale&, sal_Bool bLong )
{
// TODO: merge system information and defaults into i18n locale data
#if 0
@@ -1308,7 +1308,7 @@ sal_Bool SvXMLNumFmtDefaults::IsSystemTextualMonth( const SvtSysLocale&, BOOL bL
#endif
}
-sal_Bool SvXMLNumFmtDefaults::IsSystemLongYear( const SvtSysLocale&, BOOL bLong )
+sal_Bool SvXMLNumFmtDefaults::IsSystemLongYear( const SvtSysLocale&, sal_Bool bLong )
{
// TODO: merge system information and defaults into i18n locale data
#if 0
@@ -1318,13 +1318,13 @@ sal_Bool SvXMLNumFmtDefaults::IsSystemLongYear( const SvtSysLocale&, BOOL bLong
#endif
}
-sal_Bool SvXMLNumFmtDefaults::IsSystemLongEra( const SvtSysLocale& rSysLoc, BOOL bLong )
+sal_Bool SvXMLNumFmtDefaults::IsSystemLongEra( const SvtSysLocale& rSysLoc, sal_Bool bLong )
{
// TODO: merge system information and defaults into i18n locale data
return IsSystemLongYear( rSysLoc, bLong ); // no separate setting
}
-sal_Bool SvXMLNumFmtDefaults::IsSystemLongDayOfWeek( const SvtSysLocale&, BOOL bLong )
+sal_Bool SvXMLNumFmtDefaults::IsSystemLongDayOfWeek( const SvtSysLocale&, sal_Bool bLong )
{
// TODO: merge system information and defaults into i18n locale data
#if 0
@@ -1367,7 +1367,7 @@ sal_uInt16 SvXMLNumFmtDefaults::GetDefaultDateFormat( SvXMLDateElementAttributes
//
SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
SvXMLNumImpData* pNewData, sal_uInt16 nNewType,
const uno::Reference<xml::sax::XAttributeList>& xAttrList,
SvXMLStylesContext& rStyles ) :
@@ -1378,15 +1378,15 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
nType( nNewType ),
nKey(-1),
nFormatLang( LANGUAGE_SYSTEM ),
- bAutoOrder( FALSE ),
- bFromSystem( FALSE ),
- bTruncate( TRUE ),
- bAutoDec( FALSE ),
- bAutoInt( FALSE ),
- bHasExtraText( FALSE ),
- bHasLongDoW( FALSE ),
- bHasEra( FALSE ),
- bHasDateTime( FALSE ),
+ bAutoOrder( sal_False ),
+ bFromSystem( sal_False ),
+ bTruncate( sal_True ),
+ bAutoDec( sal_False ),
+ bAutoInt( sal_False ),
+ bHasExtraText( sal_False ),
+ bHasLongDoW( sal_False ),
+ bHasEra( sal_False ),
+ bHasDateTime( sal_False ),
bRemoveAfterUse( sal_False ),
eDateDOW( XML_DEA_NONE ),
eDateDay( XML_DEA_NONE ),
@@ -1490,7 +1490,7 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
}
SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& xAttrList,
const sal_Int32 nTempKey,
SvXMLStylesContext& rStyles ) :
@@ -1501,15 +1501,15 @@ SvXMLNumFormatContext::SvXMLNumFormatContext( SvXMLImport& rImport,
nType( 0 ),
nKey(nTempKey),
nFormatLang( LANGUAGE_SYSTEM ),
- bAutoOrder( FALSE ),
- bFromSystem( FALSE ),
- bTruncate( TRUE ),
- bAutoDec( FALSE ),
- bAutoInt( FALSE ),
- bHasExtraText( FALSE ),
- bHasLongDoW( FALSE ),
- bHasEra( FALSE ),
- bHasDateTime( FALSE ),
+ bAutoOrder( sal_False ),
+ bFromSystem( sal_False ),
+ bTruncate( sal_True ),
+ bAutoDec( sal_False ),
+ bAutoInt( sal_False ),
+ bHasExtraText( sal_False ),
+ bHasLongDoW( sal_False ),
+ bHasEra( sal_False ),
+ bHasDateTime( sal_False ),
bRemoveAfterUse( sal_False ),
eDateDOW( XML_DEA_NONE ),
eDateDay( XML_DEA_NONE ),
@@ -1528,7 +1528,7 @@ SvXMLNumFormatContext::~SvXMLNumFormatContext()
}
SvXMLImportContext* SvXMLNumFormatContext::CreateChildContext(
- USHORT nPrfx, const rtl::OUString& rLName,
+ sal_uInt16 nPrfx, const rtl::OUString& rLName,
const uno::Reference<xml::sax::XAttributeList>& xAttrList )
{
SvXMLImportContext* pContext = NULL;
@@ -1919,7 +1919,7 @@ void SvXMLNumFormatContext::AddNumber( const SvXMLNumberInfo& rInfo )
nGenPrec = 0; // generate format without decimals...
sal_Bool bGrouping = rInfo.bGrouping;
- USHORT nEmbeddedCount = rInfo.aEmbeddedElements.Count();
+ sal_uInt16 nEmbeddedCount = rInfo.aEmbeddedElements.Count();
if ( nEmbeddedCount )
bGrouping = sal_False; // grouping and embedded characters can't be used together
@@ -1962,7 +1962,7 @@ void SvXMLNumFormatContext::AddNumber( const SvXMLNumberInfo& rInfo )
}
// aEmbeddedElements is sorted with ascending positions - loop is from right to left
- for (USHORT nElement = 0; nElement < nEmbeddedCount; nElement++)
+ for (sal_uInt16 nElement = 0; nElement < nEmbeddedCount; nElement++)
{
const SvXMLEmbeddedElement* pObj = rInfo.aEmbeddedElements[nElement];
sal_Int32 nFormatPos = pObj->nFormatPos;
@@ -2298,7 +2298,7 @@ void SvXMLNumFormatContext::AddColor( const Color& rColor )
for ( sal_uInt16 i=0; i<XML_NUMF_COLORCOUNT; i++ )
if ( rColor == aNumFmtStdColors[i] )
{
- aColName = OUString( pFormatter->GetKeyword( nFormatLang, sal::static_int_cast< USHORT >(NF_KEY_FIRSTCOLOR + i) ) );
+ aColName = OUString( pFormatter->GetKeyword( nFormatLang, sal::static_int_cast< sal_uInt16 >(NF_KEY_FIRSTCOLOR + i) ) );
break;
}
@@ -2379,7 +2379,7 @@ SvXMLNumFmtHelper::~SvXMLNumFmtHelper()
}
SvXMLStyleContext* SvXMLNumFmtHelper::CreateChildContext( SvXMLImport& rImport,
- USHORT nPrefix, const OUString& rLocalName,
+ sal_uInt16 nPrefix, const OUString& rLocalName,
const uno::Reference<xml::sax::XAttributeList>& xAttrList,
SvXMLStylesContext& rStyles )
{
diff --git a/xmloff/source/style/xmlnumi.cxx b/xmloff/source/style/xmlnumi.cxx
index 7306c7d5f0de..72efeabaaca4 100644
--- a/xmloff/source/style/xmlnumi.cxx
+++ b/xmloff/source/style/xmlnumi.cxx
@@ -374,7 +374,7 @@ SvxXMLListLevelStyleContext_Impl::SvxXMLListLevelStyleContext_Impl(
if( nLevel >= 1L )
nLevel--;
else
- nLevel = 0L;
+ nLevel = 0;
break;
case XML_TOK_TEXT_LEVEL_ATTR_STYLE_NAME:
sTextStyleName = rValue;
@@ -471,7 +471,7 @@ Sequence<beans::PropertyValue> SvxXMLListLevelStyleContext_Impl::GetProperties(
{
sal_Int16 eType;
- sal_Int32 nCount = 0L;
+ sal_Int32 nCount = 0;
if( bBullet )
{
eType = NumberingType::CHAR_SPECIAL;
@@ -480,7 +480,7 @@ Sequence<beans::PropertyValue> SvxXMLListLevelStyleContext_Impl::GetProperties(
if( bImage )
{
eType = NumberingType::BITMAP;
- nCount = 15L;
+ nCount = 15;
if( (sImageURL.getLength() > 0L) || xBase64Stream.is() )
nCount++;
@@ -490,7 +490,7 @@ Sequence<beans::PropertyValue> SvxXMLListLevelStyleContext_Impl::GetProperties(
eType = NumberingType::ARABIC;
GetImport().GetMM100UnitConverter().convertNumFormat(
eType, sNumFormat, sNumLetterSync, sal_True );
- nCount = 15L;
+ nCount = 15;
}
if( ( bBullet || bNum ) && nRelSize )
@@ -505,7 +505,7 @@ Sequence<beans::PropertyValue> SvxXMLListLevelStyleContext_Impl::GetProperties(
if( nCount > 0 )
{
beans::PropertyValue *pProps = aPropSeq.getArray();
- sal_Int32 nPos = 0L;
+ sal_Int32 nPos = 0;
pProps[nPos].Name =
OUString::createFromAscii( XML_UNO_NAME_NRULE_NUMBERINGTYPE );
pProps[nPos++].Value <<= (sal_Int16)eType ;
diff --git a/xmloff/source/style/xmlprcon.cxx b/xmloff/source/style/xmlprcon.cxx
index 1a906e991f5d..b87148958ddf 100644
--- a/xmloff/source/style/xmlprcon.cxx
+++ b/xmloff/source/style/xmlprcon.cxx
@@ -39,7 +39,7 @@ using namespace ::com::sun::star;
using namespace ::std;
SvXMLPropertySetContext::SvXMLPropertySetContext(
- SvXMLImport& rImp, USHORT nPrfx,
+ SvXMLImport& rImp, sal_uInt16 nPrfx,
const OUString& rLName,
const uno::Reference< xml::sax::XAttributeList >& xAttrList,
sal_uInt32 nFam,
@@ -64,7 +64,7 @@ SvXMLPropertySetContext::~SvXMLPropertySetContext()
}
SvXMLImportContext *SvXMLPropertySetContext::CreateChildContext(
- USHORT nPrefix,
+ sal_uInt16 nPrefix,
const OUString& rLocalName,
const uno::Reference< xml::sax::XAttributeList >& xAttrList )
{
@@ -92,7 +92,7 @@ SvXMLImportContext *SvXMLPropertySetContext::CreateChildContext(
SvXMLImportItemMapper with the mid flag MID_FLAG_ELEMENT
*/
SvXMLImportContext *SvXMLPropertySetContext::CreateChildContext(
- USHORT nPrefix,
+ sal_uInt16 nPrefix,
const rtl::OUString& rLocalName,
const uno::Reference< xml::sax::XAttributeList >&,
::std::vector< XMLPropertyState > &,
diff --git a/xmloff/source/style/xmlstyle.cxx b/xmloff/source/style/xmlstyle.cxx
index 48779f48f583..108b21f43120 100644
--- a/xmloff/source/style/xmlstyle.cxx
+++ b/xmloff/source/style/xmlstyle.cxx
@@ -216,7 +216,7 @@ void SvXMLStyleContext::Finish( sal_Bool /*bOverwrite*/ )
{
}
-BOOL SvXMLStyleContext::IsTransient() const
+sal_Bool SvXMLStyleContext::IsTransient() const
{
return sal_False;
}
@@ -366,7 +366,7 @@ const SvXMLStyleContext *SvXMLStylesContext_Impl::FindStyleChildContext(
#endif
((SvXMLStylesContext_Impl *)this)->pIndices =
new SvXMLStyleIndices_Impl(
- sal::static_int_cast< USHORT >(aStyles.Count()), 5 );
+ sal::static_int_cast< sal_uInt16 >(aStyles.Count()), 5 );
for( sal_uInt32 i=0; i < aStyles.Count(); i++ )
{
SvXMLStyleIndex_Impl* pStyleIndex = new SvXMLStyleIndex_Impl( aStyles.GetObject(i));
@@ -384,7 +384,7 @@ const SvXMLStyleContext *SvXMLStylesContext_Impl::FindStyleChildContext(
if( pIndices )
{
SvXMLStyleIndex_Impl aIndex( nFamily, rName );
- ULONG nPos = 0;
+ sal_uIntPtr nPos = 0;
if( pIndices->Seek_Entry( &aIndex, &nPos ) )
pStyle = pIndices->GetObject( nPos )->GetStyle();
}
diff --git a/xmloff/source/style/xmlnumfe.cxx b/xmloff/source/style/xmlnumfe.cxx
index 93355e914759..ce1da8bc2d23 100644
--- a/xmloff/source/style/xmlnumfe.cxx
+++ b/xmloff/source/style/xmlnumfe.cxx
@@ -810,7 +810,7 @@ xub_StrLen lcl_FindSymbol( const String& sUpperStr, const String& sCurString )
sal_Bool SvXMLNumFmtExport::WriteTextWithCurrency_Impl( const OUString& rString,
const ::com::sun::star::lang::Locale& rLocale )
{
// returns TRUE if currency element was written
sal_Bool bRet = sal_False;
@@ -847,7 +847,7 @@ sal_Bool SvXMLNumFmtExport::WriteTextWithCurrency_Impl( const OUString& rString,
else
AddToTextElement_Impl( rString ); // simple text
- return bRet; // TRUE: currency element written
+ return bRet; // sal_True: currency element written
}
//-------------------------------------------------------------------------
@@ -889,7 +889,7 @@ sal_Bool lcl_IsInEmbedded( const SvXMLEmbeddedTextEntryArr& rEmbeddedEntries, sa
return sal_False; // not found
}
-BOOL lcl_IsDefaultDateFormat( const SvNumberformat& rFormat, sal_Bool bSystemDate, NfIndexTableOffset eBuiltIn )
+sal_Bool lcl_IsDefaultDateFormat( const SvNumberformat& rFormat, sal_Bool bSystemDate, NfIndexTableOffset eBuiltIn )
{
// make an extra loop to collect date elements, to check if it is a default format
// before adding the automatic-order attribute
@@ -950,7 +950,7 @@ BOOL lcl_IsDefaultDateFormat( const SvNumberformat& rFormat, sal_Bool bSystemDat
}
if ( bDateNoDefault )
- return FALSE; // additional elements
+ return sal_False; // additional elements
else
{
NfIndexTableOffset eFound = (NfIndexTableOffset) SvXMLNumFmtDefaults::GetDefaultDateFormat(
@@ -1059,7 +1059,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
// automatic ordering for currency and date formats
// only used for some built-in formats
- BOOL bAutoOrder = ( eBuiltIn == NF_CURRENCY_1000INT || eBuiltIn == NF_CURRENCY_1000DEC2 ||
+ sal_Bool bAutoOrder = ( eBuiltIn == NF_CURRENCY_1000INT || eBuiltIn == NF_CURRENCY_1000DEC2 ||
eBuiltIn == NF_CURRENCY_1000INT_RED || eBuiltIn == NF_CURRENCY_1000DEC2_RED ||
eBuiltIn == NF_CURRENCY_1000DEC2_DASHED ||
eBuiltIn == NF_DATE_SYSTEM_SHORT || eBuiltIn == NF_DATE_SYSTEM_LONG ||
@@ -1072,16 +1072,16 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
// format source (for date and time formats)
// only used for some built-in formats
- BOOL bSystemDate = ( eBuiltIn == NF_DATE_SYSTEM_SHORT ||
+ sal_Bool bSystemDate = ( eBuiltIn == NF_DATE_SYSTEM_SHORT ||
eBuiltIn == NF_DATE_SYSTEM_LONG ||
eBuiltIn == NF_DATETIME_SYSTEM_SHORT_HHMM );
- BOOL bLongSysDate = ( eBuiltIn == NF_DATE_SYSTEM_LONG );
+ sal_Bool bLongSysDate = ( eBuiltIn == NF_DATE_SYSTEM_LONG );
// check if the format definition matches the key
if ( bAutoOrder && ( nFmtType == NUMBERFORMAT_DATE || nFmtType == NUMBERFORMAT_DATETIME ) &&
!lcl_IsDefaultDateFormat( rFormat, bSystemDate, eBuiltIn ) )
{
- bAutoOrder = bSystemDate = bLongSysDate = FALSE; // don't write automatic-order attribute then
+ bAutoOrder = bSystemDate = bLongSysDate = sal_False; // don't write automatic-order attribute then
}
if ( bAutoOrder &&
@@ -1196,7 +1196,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
if ( bExpFound && pElemStr )
nExpDigits += pElemStr->Len();
else if ( !bDecDashes && pElemStr && pElemStr->GetChar(0) == '-' )
- bDecDashes = TRUE;
+ bDecDashes = sal_True;
else if ( !bVarDecimals && !bInInteger && pElemStr && pElemStr->GetChar(0) == '#' )
{
// If the decimal digits string starts with a '#', variable
@@ -1219,7 +1219,7 @@ void SvXMLNumFmtExport::ExportPart_Impl( const SvNumberformat& rFormat, sal_uInt
bInInteger = sal_False;
break;
case NF_SYMBOLTYPE_CURRENCY:
- bCurrFound = TRUE;
+ bCurrFound = sal_True;
break;
case NF_SYMBOLTYPE_CURREXT:
if (pElemStr)
@@ -810,7 +810,7 @@ xub_StrLen lcl_FindSymbol( const String& sUpperStr, const String& sCurString )
const ::com::sun::star::lang::Locale& rLocale )
{
- // returns TRUE if currency element was written
+ // returns sal_True if currency element was written
sal_Bool bRet = sal_False;